Merge branch 'issue/1050-change-default-port-to-6363'.  Refs #1050.
http://redmine.named-data.net/issues/1050
diff --git a/ndn-cpp/face.hpp b/ndn-cpp/face.hpp
index 26161ab..69f662d 100644
--- a/ndn-cpp/face.hpp
+++ b/ndn-cpp/face.hpp
@@ -30,9 +30,9 @@
   /**
    * Create a new Face for communication with an NDN hub at host:port using the default TcpTransport.
    * @param host The host of the NDN hub.
    * @param port The port of the NDN hub. If omitted. use 9695.
    */
-  Face(const char *host, unsigned short port = 9695)
+  Face(const char *host, unsigned short port = 6363)
   : node_(ptr_lib::make_shared<TcpTransport>(), 
           ptr_lib::make_shared<TcpTransport::ConnectionInfo>(host, port))
   {
@@ -30,9 +30,9 @@
    * Create a new Face for communication with an NDN hub at host:port using the default TcpTransport.
    * @param host The host of the NDN hub.
-   * @param port The port of the NDN hub. If omitted. use 9695.
+   * @param port The port of the NDN hub. If omitted. use 6363.
    */